Table

Struct Table 

pub struct Table {
Show 15 fields pub rect: Rect, pub headers: Vec<String>, pub rows: Vec<Vec<String>>, pub header_bg: ColorLinPremul, pub header_text_color: ColorLinPremul, pub cell_text_color: ColorLinPremul, pub grid_color: ColorLinPremul, pub grid_width: f32, pub bg: ColorLinPremul, pub header_font_size: f32, pub cell_font_size: f32, pub row_height: f32, pub cell_padding_x: f32, pub zebra_striping: bool, pub zebra_color: ColorLinPremul,
}
A simple table displaying headers and rows of text cells with grid lines and optional zebra striping.

Fields

rect: Rectheaders: Vec<String>

Column headers.

rows: Vec<Vec<String>>

Data rows (each row is a vec of cell strings).

header_bg: ColorLinPremul

Header background color.

header_text_color: ColorLinPremul

Header text color.

cell_text_color: ColorLinPremul

Cell text color.

grid_color: ColorLinPremul

Grid line color.

grid_width: f32

Grid line width.

bg: ColorLinPremul

Background color.

header_font_size: f32

Font size for headers.

cell_font_size: f32

Font size for cells.

row_height: f32

Row height in logical pixels.

cell_padding_x: f32

Horizontal cell padding.

zebra_striping: bool

Enable alternating row colors.

zebra_color: ColorLinPremul

Alternate row color.

Implementations

Source

impl Table

pub fn new(headers: Vec<String>) -> Self

Create a table with headers and default styling.

pub fn with_rows(self, rows: Vec<Vec<String>>) -> Self

Set data rows.

pub fn add_row(&mut self, row: Vec<String>)

Add a single row.

pub fn with_zebra(self, enabled: bool) -> Self

Enable or disable zebra striping.

pub fn hit_test(&self, x: f32, y: f32) -> bool

Hit-test.