pub struct TextArea {Show 13 fields
pub rect: Rect,
pub text: String,
pub text_size: f32,
pub text_color: ColorLinPremul,
pub placeholder: Option<String>,
pub focused: bool,
pub bg_color: ColorLinPremul,
pub border_color: ColorLinPremul,
pub border_width: f32,
pub corner_radius: f32,
pub validation_error: Option<String>,
pub cursor_position: usize,
pub focus_id: FocusId,
/* private fields */
}Expand description
A multi-line text area with vertical scrolling, cursor, and basic editing.
This is a simplified standalone version that stores text as a String.
Fields
rect: RectBounding rect.
text: StringCurrent text content.
text_size: f32Font size.
text_color: ColorLinPremulText color.
placeholder: Option<String>Placeholder text when empty.
focused: boolWhether this text area is focused.
bg_color: ColorLinPremulBackground color.
border_color: ColorLinPremulBorder color.
border_width: f32Border width.
corner_radius: f32Corner radius.
validation_error: Option<String>Validation error message.
cursor_position: usizeCursor byte position.
focus_id: FocusIdFocus identifier.
Implementations
Sourceimpl TextArea
impl TextArea
Sourcepub fn set_placeholder(&mut self, placeholder: impl Into<String>)
pub fn set_placeholder(&mut self, placeholder: impl Into<String>)
Set the placeholder text.
Sourcepub fn insert_text(&mut self, s: &str)
pub fn insert_text(&mut self, s: &str)
Insert text at the cursor position.
Sourcepub fn delete_char_before(&mut self)
pub fn delete_char_before(&mut self)
Delete one character before the cursor.
Sourcepub fn delete_char_after(&mut self)
pub fn delete_char_after(&mut self)
Delete one character after the cursor.
Sourcepub fn move_cursor_left(&mut self)
pub fn move_cursor_left(&mut self)
Move cursor left by one character.
Sourcepub fn move_cursor_right(&mut self)
pub fn move_cursor_right(&mut self)
Move cursor right by one character.
Sourcepub fn move_cursor_home(&mut self)
pub fn move_cursor_home(&mut self)
Move cursor home (beginning of current line).
Sourcepub fn move_cursor_end(&mut self)
pub fn move_cursor_end(&mut self)
Move cursor to end of current line.