Element

Trait Element 

pub trait Element: EventHandler {
    // Required methods
    fn rect(&self) -> Rect;
    fn set_rect(&mut self, rect: Rect);
    fn render(&self, canvas: &mut Canvas, z: i32);
    fn focus_id(&self) -> Option<FocusId>;
}
Trait implemented by all renderable UI elements.

Designed for object safety so that external crates (e.g., a future jag-media) can implement it for their own element types.

Required Methods

fn rect(&self) -> Rect

The bounding rectangle of this element in logical coordinates.

fn set_rect(&mut self, rect: Rect)

Update the bounding rectangle (typically called by the layout engine).

fn render(&self, canvas: &mut Canvas, z: i32)

Paint this element onto canvas at the given z-index.

fn focus_id(&self) -> Option<FocusId>

The focus identifier for this element, if it is focusable.

Implementors